from django.urls import re_path

from . import views


urlpatterns = (
    # returns knox token + user_data
    re_path(r'^social/knox_user/(?:(?P<provider>[a-zA-Z0-9_-]+)/?)?$',
            views.SocialKnoxUserAuthView.as_view(),
            name='login_social_knox_user'),

    # returns knox token only
    re_path(r'^social/knox/(?:(?P<provider>[a-zA-Z0-9_-]+)/?)?$',
            views.SocialKnoxOnlyAuthView.as_view(),
            name='login_social_knox'),
)



from django.urls import re_path

from . import views


urlpatterns = (
    # returns token only
    re_path(r'^social/jwt-sliding/(?:(?P<provider>[a-zA-Z0-9_-]+)/?)?$',
            views.SocialJWTSlidingOnlyAuthView.as_view(),
            name='login_social_jwt_sliding'),
    # returns token + user_data
    re_path(r'^social/jwt-sliding-user/(?:(?P<provider>[a-zA-Z0-9_-]+)/?)?$',
            views.SocialJWTSlidingUserAuthView.as_view(),
            name='login_social_jwt_sliding_user'),
)



import warnings

from django.utils.module_loading import import_string
from django.contrib.auth import get_user_model
from rest_framework import serializers
from rest_framework.authtoken.models import Token


class OAuth2InputSerializer(serializers.Serializer):

    provider = serializers.CharField(required=False)
    code = serializers.CharField()
    redirect_uri = serializers.CharField(required=False)


class OAuth1InputSerializer(serializers.Serializer):

    provider = serializers.CharField(required=False)
    oauth_token = serializers.CharField()
    oauth_verifier = serializers.CharField()


class UserSerializer(serializers.ModelSerializer):

    class Meta:
        model = get_user_model()
        # Custom user model may not have some fields from the list below,
        # excluding them based on actual fields
        exclude = [
            field for field in (
                'is_staff', 'is_active', 'date_joined', 'password', 'last_login',
                'user_permissions', 'groups', 'is_superuser',
            ) if field in [mfield.name for mfield in get_user_model()._meta.get_fields()]
        ]


class TokenSerializer(serializers.Serializer):

    token = serializers.SerializerMethodField()

    def get_token(self, obj):
        token, created = Token.objects.get_or_create(user=obj)
        return token.key


class UserTokenSerializer(TokenSerializer, UserSerializer):
    pass


class KnoxSerializer(TokenSerializer):
    def get_token(self, obj):
        try:
            from knox.models import AuthToken
        except ImportError:
            warnings.warn(
                'django-rest-knox must be installed for Knox authentication',
                ImportWarning,
            )
            raise

        token_instance, token_key = AuthToken.objects.create(obj)
        return token_key


class UserKnoxSerializer(KnoxSerializer, UserSerializer):
    pass


class JWTBaseSerializer(serializers.Serializer):

    jwt_token_class_name = None

    def get_token_instance(self):
        if not hasattr(self, '_jwt_token_instance'):
            if self.jwt_token_class_name is None:
                raise NotImplementedError('Must specify `jwt_token_class_name` property')
            if '.' not in self.jwt_token_class_name:
                # Maintain compatibility with class name without module path
                module_path = 'rest_framework_simplejwt.tokens'
                self.jwt_token_class_name = f'{module_path}.{self.jwt_token_class_name}'
            try:
                token_class = import_string(self.jwt_token_class_name)
            except ImportError:
                warnings.warn(
                    'djangorestframework_simplejwt must be installed for JWT authentication',
                    ImportWarning,
                )
                raise
            user = self.instance
            self._jwt_token_instance = token_class.for_user(user)
            for key, value in self.get_token_payload(user).items():
                self._jwt_token_instance[key] = value
        return self._jwt_token_instance

    def get_token_payload(self, user):
        """
        Payload defined here will be added to default mandatory payload.
        Receive User instance in argument, returns dict.
        """
        return {}


class JWTPairSerializer(JWTBaseSerializer):
    token = serializers.SerializerMethodField()
    refresh = serializers.SerializerMethodField()

    jwt_token_class_name = 'rest_framework_simplejwt.tokens.RefreshToken'

    def get_token(self, obj):
        return str(self.get_token_instance().access_token)

    def get_refresh(self, obj):
        return str(self.get_token_instance())


class UserJWTPairSerializer(JWTPairSerializer, UserSerializer):

    def get_token_payload(self, user):
        payload = dict(UserSerializer(user).data)
        payload.pop('id', None)
        return payload


class JWTSlidingSerializer(JWTBaseSerializer):
    token = serializers.SerializerMethodField()

    jwt_token_class_name = 'rest_framework_simplejwt.tokens.SlidingToken'

    def get_token(self, obj):
        return str(self.get_token_instance())


class UserJWTSlidingSerializer(JWTSlidingSerializer, UserSerializer):

    def get_token_payload(self, user):
        payload = dict(UserSerializer(user).data)
        payload.pop('id', None)
        return payload



from django.urls import re_path

from . import views


urlpatterns = (
    # returns token + user_data
    re_path(r'^social/token_user/(?:(?P<provider>[a-zA-Z0-9_-]+)/?)?$',
            views.SocialTokenUserAuthView.as_view(),
            name='login_social_token_user'),

    # returns token only
    re_path(r'^social/token/(?:(?P<provider>[a-zA-Z0-9_-]+)/?)?$',
            views.SocialTokenOnlyAuthView.as_view(),
            name='login_social_token'),)



import os
import sys
from setuptools import setup
from rest_social_auth import __author__, __version__


def __read(fname):
    try:
        return open(os.path.join(os.path.dirname(__file__), fname)).read()
    except OSError:
        return ''


if sys.argv[-1] == 'build':
    os.system('python setup.py sdist')
    os.system('python setup.py bdist_wheel')


if sys.argv[-1] == 'publish':
    # TODO: Need python 3.4.6+, 3.5.3+, Python 3.6+ here, add a check
    # https://packaging.python.org/guides/migrating-to-pypi-org/#uploading
    dists_to_upload = [
        f'dist/rest_social_auth-{__version__}.tar.gz',
        f'dist/rest_social_auth-{__version__}-py2.py3-none-any.whl',
    ]
    for dist in dists_to_upload:
        print(f'Uploading {dist}')
        os.system(f'twine upload -r pypi {dist}')
    sys.exit()


if sys.argv[-1] == 'tag':
    print("Tagging the version on github:")
    os.system(f"git tag -a v{__version__} -m 'version {__version__}'")
    os.system("git push --tags")
    sys.exit()


install_requires = __read('requirements.txt').split()

setup(
    name='rest_social_auth',
    author=__author__,
    author_email='alexevseev@gmail.com',
    version=__version__,
    description='Django rest framework resources for social auth',
    long_description=__read('README.md') + '\n\n' + __read('RELEASE_NOTES.md'),
    long_description_content_type='text/markdown; charset=UTF-8',
    platforms=('Any'),
    packages=['rest_social_auth'],
    install_requires=install_requires,
    keywords='django social auth rest login signin signup oauth'.split(),
    include_package_data=True,
    license='MIT license',
    package_dir={'rest_social_auth': 'rest_social_auth'},
    url='https://github.com/st4lk/django-rest-social-auth',
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Topic :: Utilities',
    ],
)



from django.urls import re_path

from . import views


urlpatterns = (
    re_path(r'^social/session/(?:(?P<provider>[a-zA-Z0-9_-]+)/?)?$',
            views.SocialSessionAuthView.as_view(),
            name='login_social_session'),)



from social_django.strategy import DjangoStrategy


class DRFStrategy(DjangoStrategy):

    def __init__(self, storage, request=None, tpl=None):
        self.request = request
        self.session = {}

        if request:
            try:
                self.session = request.session
            except AttributeError:
                # in case of token auth session can be disabled at all
                pass

        super(DjangoStrategy, self).__init__(storage, tpl)

    def request_data(self, merge=True):
        if self.request:
            return getattr(self.request, 'auth_data', {})
        else:
            return {}
